==> pentobi_1.0.orig.tar.gz: pentobi-1.0/src/libpentobi_gui/libpentobi_gui_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>ComputerColorDialog</name>
    <message>
        <location filename="ComputerColorDialog.cpp" line="25"/>
        <source>Computer Color</source>
        <translation>Computer-Farbe</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="30"/>
        <location filename="ComputerColorDialog.cpp" line="35"/>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="31"/>
        <location filename="ComputerColorDialog.cpp" line="38"/>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="36"/>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="37"/>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="42"/>
        <source>Blue/Red</source>
        <translation>Blau/Rot</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="43"/>
        <source>Yellow/Green</source>
        <translation>Gelb/Grün</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <location filename="GameInfoDialog.cpp" line="24"/>
        <source>Game Info</source>
        <translation>Spiel-Info</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="34"/>
        <location filename="GameInfoDialog.cpp" line="39"/>
        <source>Player Blue:</source>
        <translation>Spieler Blau:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="35"/>
        <location filename="GameInfoDialog.cpp" line="42"/>
        <source>Player Green:</source>
        <translation>Spieler Grün:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="40"/>
        <source>Player Yellow:</source>
        <translation>Spieler Gelb:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="41"/>
        <source>Player Red:</source>
        <translation>Spieler Rot:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="47"/>
        <source>Player Blue/Red:</source>
        <translation>Spieler Blau/Rot:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="49"/>
        <source>Player Yellow/Green:</source>
        <translation>Spieler Gelb/Grün:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="51"/>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="53"/>
        <source>YYYY-MM-DD</source>
        <translation>JJJJ-MM-TT</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <location filename="HelpWindow.cpp" line="27"/>
        <source>Pentobi - Help</source>
        <translation>Pentobi - Hilfe</translation>
    </message>
    <message>
        <location filename="HelpWindow.cpp" line="32"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="HelpWindow.cpp" line="35"/>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <location filename="HelpWindow.cpp" line="38"/>
        <source>Home</source>
        <translation>Startseite</translation>
    </message>
</context>
</TS>

==> pentobi_1.1.orig.tar.gz: pentobi-1.1/src/libpentobi_gui/libpentobi_gui_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>ComputerColorDialog</name>
    <message>
        <location filename="ComputerColorDialog.cpp" line="28"/>
        <source>Computer Color</source>
        <translation>Computer-Farbe</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="31"/>
        <source>Computer color:</source>
        <translation>Computer-Farbe:</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="34"/>
        <location filename="ComputerColorDialog.cpp" line="40"/>
        <location filename="ComputerColorDialog.cpp" line="47"/>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="35"/>
        <location filename="ComputerColorDialog.cpp" line="43"/>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="41"/>
        <location filename="ComputerColorDialog.cpp" line="48"/>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="42"/>
        <location filename="ComputerColorDialog.cpp" line="49"/>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="55"/>
        <source>Blue/Red</source>
        <translation>Blau/Rot</translation>
    </message>
    <message>
        <location filename="ComputerColorDialog.cpp" line="56"/>
        <source>Yellow/Green</source>
        <translation>Gelb/Grün</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <location filename="GameInfoDialog.cpp" line="26"/>
        <source>Game Info</source>
        <translation>Spiel-Info</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="36"/>
        <location filename="GameInfoDialog.cpp" line="41"/>
        <source>Player Blue:</source>
        <translation>Spieler Blau:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="37"/>
        <location filename="GameInfoDialog.cpp" line="44"/>
        <source>Player Green:</source>
        <translation>Spieler Grün:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="42"/>
        <source>Player Yellow:</source>
        <translation>Spieler Gelb:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="43"/>
        <source>Player Red:</source>
        <translation>Spieler Rot:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="49"/>
        <source>Player Blue/Red:</source>
        <translation>Spieler Blau/Rot:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="51"/>
        <source>Player Yellow/Green:</source>
        <translation>Spieler Gelb/Grün:</translation>
    </message>
    <message>
        <location filename="GameInfoDialog.cpp" line="53"/>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>YYYY-MM-DD</source>
        <translation type="obsolete">JJJJ-MM-TT</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <location filename="HelpWindow.cpp" line="27"/>
        <source>Pentobi - Help</source>
        <translation>Pentobi - Hilfe</translation>
    </message>
    <message>
        <location filename="HelpWindow.cpp" line="33"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="HelpWindow.cpp" line="39"/>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <location filename="HelpWindow.cpp" line="45"/>
        <source>Home</source>
        <translation>Startseite</translation>
    </message>
</context>
</TS>
